Index: trunk/Ohana/src/libdvo/src/dvo_convert.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert.c	(revision 19185)
@@ -288,4 +288,5 @@
   CONVERT_FORMAT ("DVO_IMAGE_PS1_DEV_1",       PS1_DEV_1,       PS1_DEV_1);
   CONVERT_FORMAT ("DVO_IMAGE_PS1_DEV_2",       PS1_DEV_2,       PS1_DEV_2);
+  CONVERT_FORMAT ("DVO_IMAGE_PS1_DEV_3",       PS1_DEV_3,       PS1_DEV_3);
 # undef CONVERT_FORMAT
 
@@ -321,4 +322,5 @@
       FORMAT_CASE (PS1_DEV_1,       PS1_DEV_1);
       FORMAT_CASE (PS1_DEV_2,       PS1_DEV_2);
+      FORMAT_CASE (PS1_DEV_3,       PS1_DEV_3);
 # undef FORMAT_CASE
 
@@ -370,4 +372,5 @@
       FORMAT_CASE (PS1_DEV_1,       PS1_DEV_1);
       FORMAT_CASE (PS1_DEV_2,       PS1_DEV_2);
+      FORMAT_CASE (PS1_DEV_3,       PS1_DEV_3);
 # undef FORMAT_CASE
 
Index: trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_1.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_1.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_1.c	(revision 19185)
@@ -194,5 +194,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // out[128], in[64]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -249,5 +251,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // out[128], in[64]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
Index: trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_2.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_2.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_2.c	(revision 19185)
@@ -200,5 +200,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // out[128], int[64]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -256,5 +258,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // in[128], out[64]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
Index: trunk/Ohana/src/libdvo/src/dvo_convert_elixir.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_elixir.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_elixir.c	(revision 19185)
@@ -199,5 +199,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name); // out[64], in[32]
+
+    strncpy (out[i].name, in[i].name, 31); // in[32], out[128]
+    out[i].name[31] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -258,5 +260,6 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strncpy (out[i].name, in[i].name, 31); // out[32], in[64]
+
+    strncpy (out[i].name, in[i].name, 31); // out[32], in[128]
     out[i].name[31] = 0; // force termination
 
Index: trunk/Ohana/src/libdvo/src/dvo_convert_loneos.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_loneos.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_loneos.c	(revision 19185)
@@ -189,5 +189,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name); // out[64], in[32]
+
+    strncpy (out[i].name, in[i].name, 31); // in[32], out[128]
+    out[i].name[31] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -245,5 +247,6 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strncpy (out[i].name, in[i].name, 31); // out[32], in[64]
+
+    strncpy (out[i].name, in[i].name, 31); // out[32], in[128]
     out[i].name[31] = 0; // force termination
 
Index: trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_0.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_0.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_0.c	(revision 19185)
@@ -202,5 +202,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name); // out[64], in[32]
+
+    strncpy (out[i].name, in[i].name, 31); // out[128], in[32]
+    out[i].name[31] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -257,5 +259,6 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strncpy (out[i].name, in[i].name, 31); // out[32], in[64]
+
+    strncpy (out[i].name, in[i].name, 31); // out[32], in[128]
     out[i].name[31] = 0; // force termination
 
Index: trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_1.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_1.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_panstarrs_DEV_1.c	(revision 19185)
@@ -202,5 +202,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // in[64], out[128]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
@@ -257,5 +259,7 @@
   for (i = 0; i < Nvalues; i++) {
     memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
-    strcpy (out[i].name, in[i].name);
+
+    strncpy (out[i].name, in[i].name, 63); // in[128], out[64]
+    out[i].name[63] = 0; // force termination
 
     out[i].tzero    	    = in[i].tzero;
Index: trunk/Ohana/src/libdvo/src/dvo_image.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_image.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_image.c	(revision 19185)
@@ -195,4 +195,5 @@
   if (db[0].format == DVO_FORMAT_PS1_DEV_1)       gfits_modify (&db[0].header, "FORMAT", "%s", 1, "PS1_DEV_1");
   if (db[0].format == DVO_FORMAT_PS1_DEV_2)       gfits_modify (&db[0].header, "FORMAT", "%s", 1, "PS1_DEV_2");
+  if (db[0].format == DVO_FORMAT_PS1_DEV_3)       gfits_modify (&db[0].header, "FORMAT", "%s", 1, "PS1_DEV_3");
   
   return;

Index: trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_3.c
===================================================================
--- trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_3.c	(revision 17419)
+++ trunk/Ohana/src/libdvo/src/dvo_convert_PS1_DEV_3.c	(revision 19185)
@@ -3,5 +3,121 @@
 /* convert PS1_DEV_3 formats to internal formats */
 
-// XXX I am not yet ready to commit to a full PS1_DEV_3 release, but we can add photcode here for now
+// XXX EAM I am not yet ready to commit to a full PS1_DEV_3 release, but I am providing image and photcode conversion
+
+Image *Image_PS1_DEV_3_ToInternal (Image_PS1_DEV_3 *in, int Nvalues) {
+
+  int i;
+  Image *out;
+
+  ALLOCATE (out, Image, Nvalues);
+
+  for (i = 0; i < Nvalues; i++) {
+    memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
+
+    strncpy (out[i].name, in[i].name, 127); // out[128], in[128]
+    out[i].name[127] = 0; // force termination
+
+    out[i].tzero    	    = in[i].tzero;
+    out[i].nstar    	    = in[i].nstar;
+    out[i].secz	    	    = in[i].secz;
+    out[i].NX	    	    = in[i].NX;
+    out[i].NY	    	    = in[i].NY;
+    out[i].apmifit  	    = in[i].apmifit;
+    out[i].dapmifit 	    = in[i].dapmifit;
+    out[i].Mcal	    	    = in[i].Mcal;
+    out[i].dMcal    	    = in[i].dMcal;
+    out[i].Xm	    	    = in[i].Xm;
+    out[i].photcode   	    = in[i].photcode;
+    out[i].exptime  	    = in[i].exptime;
+    out[i].sidtime  	    = in[i].sidtime;
+    out[i].latitude  	    = in[i].latitude;
+    out[i].detection_limit  = in[i].detection_limit;
+    out[i].saturation_limit = in[i].saturation_limit;
+    out[i].cerror	    = in[i].cerror;
+    out[i].fwhm_x	    = in[i].fwhm_x;
+    out[i].fwhm_y	    = in[i].fwhm_y;
+    out[i].trate	    = in[i].trate;
+    out[i].code		    = in[i].code;
+    out[i].ccdnum	    = in[i].ccdnum;
+    out[i].imageID	    = in[i].imageID;
+    out[i].externID	    = in[i].externID;
+    out[i].sourceID	    = in[i].sourceID;
+
+    out[i].order	    = in[i].order;
+    out[i].Mx		    = in[i].Mx;
+    out[i].My		    = in[i].My;
+    out[i].Mxx		    = in[i].Mxx;
+    out[i].Mxy		    = in[i].Mxy;
+    out[i].Myy		    = in[i].Myy;
+    out[i].Mxxx		    = in[i].Mxxx;
+    out[i].Mxxy		    = in[i].Mxxy;
+    out[i].Mxyy		    = in[i].Mxyy;
+    out[i].Myyy		    = in[i].Myyy;
+    out[i].Mxxxx	    = in[i].Mxxxx;
+    out[i].Mxxxy	    = in[i].Mxxxy;
+    out[i].Mxxyy	    = in[i].Mxxyy;
+    out[i].Mxyyy	    = in[i].Mxyyy;
+    out[i].Myyyy	    = in[i].Myyyy;
+  }
+  return (out);
+}
+
+Image_PS1_DEV_3 *ImageInternalTo_PS1_DEV_3 (Image *in, int Nvalues) {
+
+  int i;
+  Image_PS1_DEV_3 *out;
+
+  ALLOCATE (out, Image_PS1_DEV_3, Nvalues);
+
+  for (i = 0; i < Nvalues; i++) {
+    memcpy (&out[i].coords, &in[i].coords, sizeof(Coords));
+
+    strncpy (out[i].name, in[i].name, 127); // out[128], in[128]
+    out[i].name[127] = 0; // force termination
+
+    out[i].tzero    	    = in[i].tzero;
+    out[i].nstar    	    = in[i].nstar;
+    out[i].secz	    	    = in[i].secz;
+    out[i].NX	    	    = in[i].NX;
+    out[i].NY	    	    = in[i].NY;
+    out[i].apmifit  	    = in[i].apmifit;
+    out[i].dapmifit 	    = in[i].dapmifit;
+    out[i].Mcal	    	    = in[i].Mcal;
+    out[i].dMcal    	    = in[i].dMcal;
+    out[i].Xm	    	    = in[i].Xm;
+    out[i].photcode   	    = in[i].photcode;
+    out[i].exptime  	    = in[i].exptime;
+    out[i].sidtime  	    = in[i].sidtime;
+    out[i].latitude  	    = in[i].latitude;
+    out[i].detection_limit  = in[i].detection_limit;
+    out[i].saturation_limit = in[i].saturation_limit;
+    out[i].cerror	    = in[i].cerror;
+    out[i].fwhm_x	    = in[i].fwhm_x;
+    out[i].fwhm_y	    = in[i].fwhm_y;
+    out[i].trate	    = in[i].trate;
+    out[i].code		    = in[i].code;
+    out[i].ccdnum	    = in[i].ccdnum;
+    out[i].imageID	    = in[i].imageID;
+    out[i].externID	    = in[i].externID;
+    out[i].sourceID	    = in[i].sourceID;
+
+    out[i].order	    = in[i].order;
+    out[i].Mx		    = in[i].Mx;
+    out[i].My		    = in[i].My;
+    out[i].Mxx		    = in[i].Mxx;
+    out[i].Mxy		    = in[i].Mxy;
+    out[i].Myy		    = in[i].Myy;
+    out[i].Mxxx		    = in[i].Mxxx;
+    out[i].Mxxy		    = in[i].Mxxy;
+    out[i].Mxyy		    = in[i].Mxyy;
+    out[i].Myyy		    = in[i].Myyy;
+    out[i].Mxxxx	    = in[i].Mxxxx;
+    out[i].Mxxxy	    = in[i].Mxxxy;
+    out[i].Mxxyy	    = in[i].Mxxyy;
+    out[i].Mxyyy	    = in[i].Mxyyy;
+    out[i].Myyyy	    = in[i].Myyyy;
+  }
+  return (out);
+}
 
 PhotCode_PS1_DEV_3 *PhotCode_Internal_To_PS1_DEV_3 (PhotCode *in, int Nvalues) {